@@ -62,12 +62,11 @@ parseSAG <- function(x) {
   x[x == ""] <- NA
   x[x == "NA"] <- NA
 
-  # make into a data.frame
+  # convert to data frame
   dim(x) <- c(ncol, length(x)/ncol)
   row.names(x) <- names_x
   x <- as.data.frame(t(x), stringsAsFactors = FALSE)
 
-  # simplify and return
   simplify(x)
 }
 
@@ -75,7 +74,11 @@ parseSAG <- function(x) {
 
 parseSummary <- function(x) {
 
-  # check for not published:
+  if (length(x) < 3) {
+    warning("A summary table was not downloaded")
+    return(NULL)
+  }
+  # check for not published
   if ( gsub(" *<.*?>", "", x[3]) == "Stock not published") {
     return(NULL)
   }
@@ -93,10 +96,14 @@ parseSummary <- function(x) {
   info <- x[3:(starts[1]-2)]
   # match content of first <tag>
   names_info <- gsub(" *<(.*?)>.*", "\\1", info)
+  # also remove xsi:nil:
+  names_info <- gsub(" xsi:nil=\"true\" /", "", names_info)
+  names_info <- gsub(" [/]", "", names_info)
   # delete all <tags>
   info <- gsub(" *<.*?>", "", info)
   names(info) <- names_info
 
+
   # read summary table
   x <- x[-c(1:(starts[1]-1), starts, ends, length(x) + -1:0)]
 
@@ -108,7 +115,7 @@ parseSummary <- function(x) {
   # delete all <tags>
   x <- gsub(" *<.*?>", "", x)
 
-  # make into a data.frame
+  # convert to data frame
   dim(x) <- c(ncol, length(x)/ncol)
   row.names(x) <- names_x
   x <- as.data.frame(t(x), stringsAsFactors = FALSE)
@@ -120,7 +127,6 @@ parseSummary <- function(x) {
   x[x == ""] <- NA
   x[x == "NA"] <- NA
 
-  # simplify
   simplify(x)
 }
 
